@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import ast
 import unittest
 import os.path
@@ -8,7 +6,6 @@ import inspect
 import textwrap
 import collections
 import re
-from six import PY3
 
 try:
     from numpydoc.docscrape import NumpyDocString
@@ -241,12 +238,8 @@ class LintTestCase(unittest.TestCase):
         # Do require documentation of *args and **kwargs
         if argspec.varargs:
             arg_set |= {'*' + argspec.varargs}
-        if PY3:
-            if argspec.varkw:
-                arg_set |= {'**' + argspec.varkw}
-        else:
-            if argspec.keywords:
-                arg_set |= {'**' + argspec.keywords}
+        if argspec.varkw:
+            arg_set |= {'**' + argspec.varkw}
 
         if len(arg_set) >= 1:
             if not numpy_doc_string['Parameters']:
@@ -314,13 +307,7 @@ class LintTestCase(unittest.TestCase):
         dedented_src = textwrap.dedent(method_src)
 
         f = ReturnFinder()
-        try:
-            f.visit(ast.parse(dedented_src))
-        except SyntaxError:
-            # ast.parse in python 2 will fail if we use certain print function syntax in
-            # our function.
-            dedented_src = 'from __future__ import print_function\n' + dedented_src
-            f.visit(ast.parse(dedented_src))
+        f.visit(ast.parse(dedented_src))
 
         # If the function does nothing but pass, return
         if f.passes:
@@ -374,10 +361,7 @@ class LintTestCase(unittest.TestCase):
             with information about every failure. Form is
             { 'dir_name/file_name:class_name.method_name': [ messages ] }
         """
-        if PY3:
-            argspec = inspect.getfullargspec(method)
-        else:
-            argspec = inspect.getargspec(method)
+        argspec = inspect.getfullargspec(method)
         doc = inspect.getdoc(method)
 
         new_failures = []
@@ -473,10 +457,7 @@ class LintTestCase(unittest.TestCase):
             { 'dir_name/file_name:class_name.method_name': [ messages ] }
         """
 
-        if PY3:
-            argspec = inspect.getfullargspec(func)
-        else:
-            argspec = inspect.getargspec(func)
+        argspec = inspect.getfullargspec(func)
         doc = inspect.getdoc(func)
 
         new_failures = []
