@@ -70,7 +70,24 @@ class MetaModelUnStructuredComp(ExplicitComponent):
         self._static_surrogate_output_names = []
         self._static_input_size = 0
 
-    def _setup_procs(self, pathname, comm, mode, setup_mode, prob_options):
+    def _setup_procs(self, pathname, comm, mode, prob_meta):
+        """
+        Execute first phase of the setup process.
+
+        Distribute processors, assign pathnames, and call setup on the component.
+
+        Parameters
+        ----------
+        pathname : str
+            Global name of the system, including the path.
+        comm : MPI.Comm or <FakeComm>
+            MPI communicator object.
+        mode : str
+            Derivatives calculation mode, 'fwd' for forward, and 'rev' for
+            reverse (adjoint).
+        prob_meta : dict
+            Problem level options.
+        """
         self._surrogate_input_names = []
         self._surrogate_output_names = []
 
@@ -78,8 +95,7 @@ class MetaModelUnStructuredComp(ExplicitComponent):
         self._surrogate_output_names.extend(self._static_surrogate_output_names)
         self._input_size = self._static_input_size
 
-        super(MetaModelUnStructuredComp, self)._setup_procs(pathname, comm, mode, setup_mode,
-                                                            prob_options)
+        super(MetaModelUnStructuredComp, self)._setup_procs(pathname, comm, mode, prob_meta)
 
     def initialize(self):
         """
@@ -197,16 +213,11 @@ class MetaModelUnStructuredComp(ExplicitComponent):
 
         return metadata
 
-    def _setup_var_data(self, recurse=True):
+    def _setup_var_data(self):
         """
         Count total variables.
 
         Also instantiates surrogates for the output variables that use the default surrogate.
-
-        Parameters
-        ----------
-        recurse : bool
-            Whether to call this method in subsystems.
         """
         default_surrogate = self.options['default_surrogate']
         for name, shape in self._surrogate_output_names:
@@ -224,18 +235,13 @@ class MetaModelUnStructuredComp(ExplicitComponent):
         # training will occur on first execution after setup
         self.train = True
 
-        super(MetaModelUnStructuredComp, self)._setup_var_data(recurse=recurse)
+        super(MetaModelUnStructuredComp, self)._setup_var_data()
 
-    def _setup_partials(self, recurse=True):
+    def _setup_partials(self):
         """
         Process all partials and approximations that the user declared.
 
         Metamodel needs to declare its partials after inputs and outputs are known.
-
-        Parameters
-        ----------
-        recurse : bool
-            Whether to call this method in subsystems.
         """
         super(MetaModelUnStructuredComp, self)._setup_partials()
 
