@@ -6,6 +6,8 @@ import numpy as np
 from numpy.testing import assert_almost_equal
 import scipy
 
+from distutils.version import LooseVersion
+
 try:
     from parameterized import parameterized
 except ImportError:
@@ -13,7 +15,7 @@ except ImportError:
 
 import openmdao.api as om
 from openmdao.components.exec_comp import _expr_dict
-from openmdao.utils.assert_utils import assert_rel_error
+from openmdao.utils.assert_utils import assert_near_equal, assert_check_partials, assert_warning
 
 _ufunc_test_data = {
     'abs': {
@@ -115,11 +117,6 @@ _ufunc_test_data = {
         'check_func': np.expm1,
         'args': {'f': {'value': np.zeros(6)},
                  'x': {'value': np.random.random(6)}}},
-    'factorial': {
-        'str': 'f=factorial(x)',
-        'check_func': scipy.special.factorial,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)}}},
     'fmax': {
         'str': 'f=fmax(x, y)',
         'check_func': np.fmax,
@@ -254,6 +251,28 @@ _ufunc_test_data = {
 }
 
 
+# 'factorial' will raise a RuntimeError or a deprecation warning depending on scipy version
+if LooseVersion(scipy.__version__) >= LooseVersion("1.5.0"):
+    _ufunc_test_data['factorial'] = {
+        'str': 'f=factorial(x)',
+        'args': {'f': {'value': np.zeros(6)},
+                 'x': {'value': np.random.random(6)}},
+        'error': (RuntimeError,
+                  "The 'factorial' function is not supported for SciPy "
+                  f"versions >= 1.5, current version: {scipy.__version__}")
+    }
+else:
+    _ufunc_test_data['factorial'] = {
+        'str': 'f=factorial(x)',
+        'check_func': scipy.special.factorial,
+        'args': {'f': {'value': np.zeros(6)},
+                 'x': {'value': np.random.random(6)}},
+        'warning': (DeprecationWarning,
+                    "The 'factorial' function is deprecated. "
+                    "It is no longer supported for SciPy versions >= 1.5.")
+    }
+
+
 class TestExecComp(unittest.TestCase):
 
     def test_no_expr(self):
@@ -333,7 +352,7 @@ class TestExecComp(unittest.TestCase):
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, C1._outputs['y'], 45.0, 0.00001)
+        assert_near_equal(C1._outputs['y'], 45.0, 0.00001)
 
     def test_simple(self):
         prob = om.Problem()
@@ -350,7 +369,7 @@ class TestExecComp(unittest.TestCase):
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, C1._outputs['y'], 3.0, 0.00001)
+        assert_near_equal(C1._outputs['y'], 3.0, 0.00001)
 
     def test_for_spaces(self):
         prob = om.Problem()
@@ -368,7 +387,7 @@ class TestExecComp(unittest.TestCase):
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, C1._outputs['y'], 2 * math.pi, 0.00001)
+        assert_near_equal(C1._outputs['y'], 2 * math.pi, 0.00001)
 
     def test_units(self):
         prob = om.Problem()
@@ -384,7 +403,7 @@ class TestExecComp(unittest.TestCase):
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, C1._outputs['y'], 4.0, 0.00001)
+        assert_near_equal(C1._outputs['y'], 4.0, 0.00001)
 
     def test_units_varname(self):
         prob = om.Problem()
@@ -437,7 +456,7 @@ class TestExecComp(unittest.TestCase):
         prob.setup()
         prob.run_model()
 
-        assert_rel_error(self, prob['comp.y'], 4.0, 0.00001)
+        assert_near_equal(prob['comp.y'], 4.0, 0.00001)
 
     def test_common_units_no_meta(self):
         # make sure common units are assigned when no metadata is provided
@@ -451,7 +470,7 @@ class TestExecComp(unittest.TestCase):
         prob.setup()
         prob.run_model()
 
-        assert_rel_error(self, prob['comp.y'], 2001., 0.00001)
+        assert_near_equal(prob['comp.y'], 2001., 0.00001)
 
     def test_conflicting_units(self):
         prob = om.Problem()
@@ -587,7 +606,7 @@ class TestExecComp(unittest.TestCase):
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, C1._outputs['y'], math.sin(2.0), 0.00001)
+        assert_near_equal(C1._outputs['y'], math.sin(2.0), 0.00001)
 
     def test_np(self):
         prob = om.Problem()
@@ -645,7 +664,7 @@ class TestExecComp(unittest.TestCase):
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, C1._outputs['y'], 2.0, 0.00001)
+        assert_near_equal(C1._outputs['y'], 2.0, 0.00001)
 
     def test_array_lhs(self):
         prob = om.Problem()
@@ -664,7 +683,7 @@ class TestExecComp(unittest.TestCase):
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, C1._outputs['y'], np.array([2., 1.]), 0.00001)
+        assert_near_equal(C1._outputs['y'], np.array([2., 1.]), 0.00001)
 
     def test_simple_array_model(self):
         prob = om.Problem()
@@ -681,12 +700,7 @@ class TestExecComp(unittest.TestCase):
 
         data = prob.check_partials(out_stream=None)
 
-        assert_rel_error(self, data['comp'][('y', 'x')]['abs error'][0], 0.0, 1e-5)
-        assert_rel_error(self, data['comp'][('y', 'x')]['abs error'][1], 0.0, 1e-5)
-        assert_rel_error(self, data['comp'][('y', 'x')]['abs error'][2], 0.0, 1e-5)
-        assert_rel_error(self, data['comp'][('y', 'x')]['rel error'][0], 0.0, 1e-5)
-        assert_rel_error(self, data['comp'][('y', 'x')]['rel error'][1], 0.0, 1e-5)
-        assert_rel_error(self, data['comp'][('y', 'x')]['rel error'][2], 0.0, 1e-5)
+        assert_check_partials(data, atol=1e-5, rtol=1e-5)
 
     def test_simple_array_model2(self):
         prob = om.Problem()
@@ -703,12 +717,7 @@ class TestExecComp(unittest.TestCase):
 
         data = prob.check_partials(out_stream=None)
 
-        assert_rel_error(self, data['comp'][('y', 'x')]['abs error'][0], 0.0, 1e-5)
-        assert_rel_error(self, data['comp'][('y', 'x')]['abs error'][1], 0.0, 1e-5)
-        assert_rel_error(self, data['comp'][('y', 'x')]['abs error'][2], 0.0, 1e-5)
-        assert_rel_error(self, data['comp'][('y', 'x')]['rel error'][0], 0.0, 1e-5)
-        assert_rel_error(self, data['comp'][('y', 'x')]['rel error'][1], 0.0, 1e-5)
-        assert_rel_error(self, data['comp'][('y', 'x')]['rel error'][2], 0.0, 1e-5)
+        assert_check_partials(data, atol=1e-5, rtol=1e-5)
 
     def test_complex_step(self):
         prob = om.Problem()
@@ -725,11 +734,11 @@ class TestExecComp(unittest.TestCase):
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, C1._outputs['y'], 5.0, 0.00001)
+        assert_near_equal(C1._outputs['y'], 5.0, 0.00001)
 
         C1._linearize()
 
-        assert_rel_error(self, C1._jacobian[('y', 'x')], [[2.0]], 0.00001)
+        assert_near_equal(C1._jacobian[('y', 'x')], [[2.0]], 0.00001)
 
     def test_complex_step2(self):
         prob = om.Problem(om.Group())
@@ -742,13 +751,13 @@ class TestExecComp(unittest.TestCase):
         prob.run_model()
 
         J = prob.compute_totals(['comp.y'], ['p1.x'], return_format='flat_dict')
-        assert_rel_error(self, J['comp.y', 'p1.x'], np.array([[6.0]]), 0.00001)
+        assert_near_equal(J['comp.y', 'p1.x'], np.array([[6.0]]), 0.00001)
 
         prob.setup(check=False, mode='rev')
         prob.run_model()
 
         J = prob.compute_totals(['comp.y'], ['p1.x'], return_format='flat_dict')
-        assert_rel_error(self, J['comp.y', 'p1.x'], np.array([[6.0]]), 0.00001)
+        assert_near_equal(J['comp.y', 'p1.x'], np.array([[6.0]]), 0.00001)
 
     def test_abs_complex_step(self):
         prob = om.Problem()
@@ -758,20 +767,20 @@ class TestExecComp(unittest.TestCase):
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, C1._outputs['y'], 4.0, 0.00001)
+        assert_near_equal(C1._outputs['y'], 4.0, 0.00001)
 
         # any positive C1.x should give a 2.0 derivative for dy/dx
         C1._inputs['x'] = 1.0e-10
         C1._linearize()
-        assert_rel_error(self, C1._jacobian['y', 'x'], [[2.0]], 0.00001)
+        assert_near_equal(C1._jacobian['y', 'x'], [[2.0]], 0.00001)
 
         C1._inputs['x'] = -3.0
         C1._linearize()
-        assert_rel_error(self, C1._jacobian['y', 'x'], [[-2.0]], 0.00001)
+        assert_near_equal(C1._jacobian['y', 'x'], [[-2.0]], 0.00001)
 
         C1._inputs['x'] = 0.0
         C1._linearize()
-        assert_rel_error(self, C1._jacobian['y', 'x'], [[2.0]], 0.00001)
+        assert_near_equal(C1._jacobian['y', 'x'], [[2.0]], 0.00001)
 
     def test_abs_array_complex_step(self):
         prob = om.Problem()
@@ -782,20 +791,20 @@ class TestExecComp(unittest.TestCase):
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, C1._outputs['y'], np.ones(3)*4.0, 0.00001)
+        assert_near_equal(C1._outputs['y'], np.ones(3)*4.0, 0.00001)
 
         # any positive C1.x should give a 2.0 derivative for dy/dx
         C1._inputs['x'] = np.ones(3)*1.0e-10
         C1._linearize()
-        assert_rel_error(self, C1._jacobian['y', 'x'], np.eye(3)*2.0, 0.00001)
+        assert_near_equal(C1._jacobian['y', 'x'], np.eye(3)*2.0, 0.00001)
 
         C1._inputs['x'] = np.ones(3)*-3.0
         C1._linearize()
-        assert_rel_error(self, C1._jacobian['y', 'x'], np.eye(3)*-2.0, 0.00001)
+        assert_near_equal(C1._jacobian['y', 'x'], np.eye(3)*-2.0, 0.00001)
 
         C1._inputs['x'] = np.zeros(3)
         C1._linearize()
-        assert_rel_error(self, C1._jacobian['y', 'x'], np.eye(3)*2.0, 0.00001)
+        assert_near_equal(C1._jacobian['y', 'x'], np.eye(3)*2.0, 0.00001)
 
         C1._inputs['x'] = np.array([1.5, -0.6, 2.4])
         C1._linearize()
@@ -804,7 +813,7 @@ class TestExecComp(unittest.TestCase):
         expect[1, 1] = -2.0
         expect[2, 2] = 2.0
 
-        assert_rel_error(self, C1._jacobian['y', 'x'], expect, 0.00001)
+        assert_near_equal(C1._jacobian['y', 'x'], expect, 0.00001)
 
     def test_has_diag_partials_error(self):
         p = om.Problem()
@@ -905,17 +914,18 @@ class TestExecComp(unittest.TestCase):
 
         p = om.Problem()
         model = p.model
-        model.add_subsystem('indep', om.IndepVarComp('x', val=np.ones(5)))
 
         model.add_subsystem('comp', om.ExecComp('y=3.0*x + 2.5',
                                                 has_diag_partials=True,
                                                 x=np.ones(5), y=np.ones(5)))
-        model.connect('indep.x', 'comp.x')
 
         p.setup()
+
+        p.set_val('comp.x', np.ones(5))
+
         p.run_model()
 
-        J = p.compute_totals(of=['comp.y'], wrt=['indep.x'], return_format='array')
+        J = p.compute_totals(of=['comp.y'], wrt=['comp.x'], return_format='array')
 
         assert_almost_equal(J, np.eye(5)*3., decimal=6)
 
@@ -925,17 +935,16 @@ class TestExecComp(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p', om.IndepVarComp('x', 2.0))
         model.add_subsystem('comp', om.ExecComp('y=x+1.'))
 
-        model.connect('p.x', 'comp.x')
+        model.set_input_defaults('comp.x', 2.0)
 
         prob.setup()
 
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, prob['comp.y'], 3.0, 0.00001)
+        assert_near_equal(prob.get_val('comp.y'), 3.0, 0.00001)
 
     def test_feature_multi_output(self):
         import openmdao.api as om
@@ -943,18 +952,17 @@ class TestExecComp(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p', om.IndepVarComp('x', 2.0))
-        model.add_subsystem('comp', om.ExecComp(['y1=x+1.', 'y2=x-1.']))
-
-        model.connect('p.x', 'comp.x')
+        model.add_subsystem('comp', om.ExecComp(['y1=x+1.', 'y2=x-1.']), promotes=['x'])
 
         prob.setup()
 
+        prob.set_val('x', 2.0)
+
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, prob['comp.y1'], 3.0, 0.00001)
-        assert_rel_error(self, prob['comp.y2'], 1.0, 0.00001)
+        assert_near_equal(prob.get_val('comp.y1'), 3.0, 0.00001)
+        assert_near_equal(prob.get_val('comp.y2'), 1.0, 0.00001)
 
     def test_feature_array(self):
         import numpy as np
@@ -964,18 +972,16 @@ class TestExecComp(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p', om.IndepVarComp('x', np.array([1., 2., 3.])))
         model.add_subsystem('comp', om.ExecComp('y=x[1]',
                                                 x=np.array([1., 2., 3.]),
                                                 y=0.0))
-        model.connect('p.x', 'comp.x')
 
         prob.setup()
 
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, prob['comp.y'], 2.0, 0.00001)
+        assert_near_equal(prob.get_val('comp.y'), 2.0, 0.00001)
 
     def test_feature_math(self):
         import numpy as np
@@ -985,19 +991,17 @@ class TestExecComp(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p1', om.IndepVarComp('x', np.pi/2.0))
-        model.add_subsystem('p2', om.IndepVarComp('y', np.pi/2.0))
         model.add_subsystem('comp', om.ExecComp('z = sin(x)**2 + cos(y)**2'))
 
-        model.connect('p1.x', 'comp.x')
-        model.connect('p2.y', 'comp.y')
-
         prob.setup()
 
+        prob.set_val('comp.x', np.pi/2.0)
+        prob.set_val('comp.y', np.pi/2.0)
+
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, prob['comp.z'], 1.0, 0.00001)
+        assert_near_equal(prob.get_val('comp.z'), 1.0, 0.00001)
 
     def test_feature_numpy(self):
         import numpy as np
@@ -1016,7 +1020,7 @@ class TestExecComp(unittest.TestCase):
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, prob['comp.y'], 6.0, 0.00001)
+        assert_near_equal(prob['comp.y'], 6.0, 0.00001)
 
     def test_feature_metadata(self):
         import openmdao.api as om
@@ -1024,42 +1028,38 @@ class TestExecComp(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p1', om.IndepVarComp('x', 12.0, units='inch'))
-        model.add_subsystem('p2', om.IndepVarComp('y', 1.0, units='ft'))
         model.add_subsystem('comp', om.ExecComp('z=x+y',
                                                 x={'value': 0.0, 'units': 'inch'},
                                                 y={'value': 0.0, 'units': 'inch'},
                                                 z={'value': 0.0, 'units': 'inch'}))
-        model.connect('p1.x', 'comp.x')
-        model.connect('p2.y', 'comp.y')
 
         prob.setup()
 
+        prob.set_val('comp.x', 12.0, units='inch')
+        prob.set_val('comp.y', 1.0, units='ft')
+
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, prob['comp.z'], 24.0, 0.00001)
+        assert_near_equal(prob.get_val('comp.z'), 24.0, 0.00001)
 
     def test_feature_options(self):
         import openmdao.api as om
 
         model = om.Group()
 
-        indep = model.add_subsystem('indep', om.IndepVarComp('x', shape=(2,), units='cm'))
         xcomp = model.add_subsystem('comp', om.ExecComp('y=2*x', shape=(2,)))
 
         xcomp.options['units'] = 'm'
 
-        model.connect('indep.x', 'comp.x')
-
         prob = om.Problem(model)
         prob.setup()
 
-        prob['indep.x'] = [100., 200.]
+        prob.set_val('comp.x', [100., 200.], units='cm')
 
         prob.run_model()
 
-        assert_rel_error(self, prob['comp.y'], [2., 4.], 0.00001)
+        assert_near_equal(prob.get_val('comp.y'), [2., 4.], 0.00001)
 
 
 class TestExecCompParameterized(unittest.TestCase):
@@ -1084,7 +1084,18 @@ class TestExecCompParameterized(unittest.TestCase):
         model.add_subsystem('comp', om.ExecComp(test_data['str'], **test_data['args']),
                             promotes_outputs=['f'])
         prob.setup()
-        prob.run_model()
+
+        if 'error' in test_data:
+            err, msg = test_data['error']
+            with self.assertRaises(err) as cm:
+                prob.run_model()
+            self.assertTrue(msg in str(cm.exception))
+            return
+        elif 'warning' in test_data:
+            with assert_warning(*test_data['warning']):
+                prob.run_model()
+        else:
+            prob.run_model()
 
         if 'check_func' in test_data:
             check_args = []
@@ -1131,14 +1142,25 @@ class TestExecCompParameterized(unittest.TestCase):
                             om.ExecComp(test_data['str'], **test_data['args']),
                             promotes_outputs=['f'])
         prob.setup()
-        prob.run_model()
+
+        if 'error' in test_data:
+            err, msg = test_data['error']
+            with self.assertRaises(err) as cm:
+                prob.run_model()
+            self.assertTrue(msg in str(cm.exception))
+            return
+        elif 'warning' in test_data:
+            with assert_warning(*test_data['warning']):
+                prob.run_model()
+        else:
+            prob.run_model()
 
         if 'check_val' not in test_data:
             cpd = prob.check_partials(out_stream=None)
 
             for comp in cpd:
                 for (var, wrt) in cpd[comp]:
-                    np.testing.assert_almost_equal(cpd[comp][var, wrt]['abs error'], 0, decimal=4)
+                    np.testing.assert_almost_equal(cpd[comp][var, wrt]['abs error'][0], 0, decimal=4)
 
 
 if __name__ == "__main__":
