@@ -276,7 +276,7 @@ class SplineCompTestCase(unittest.TestCase):
 
         derivs = prob.check_partials(out_stream=None, method='cs')
         assert_check_partials(derivs, atol=1e-14, rtol=1e-14)
-        
+
     def test_bspline_bug(self):
         # Tests a bug fix where the interp_options weren't passed into
         # the bspline interp comp
@@ -289,7 +289,7 @@ class SplineCompTestCase(unittest.TestCase):
         comp.add_spline(y_cp_name='alt_cp', y_interp_name='alt', y_cp_val=self.y_cp, y_units='kft')
 
         self.prob.setup(force_alloc_complex=True)
-        
+
         # If we set the bspline order to 3, then k should internally be 4
         self.assertEqual(comp.interps['alt'].table.k, 4)
 
@@ -406,7 +406,7 @@ class SplineCompFeatureTestCase(unittest.TestCase):
                             20.96983509, 21.37579297, 21.94811407, 22.66809748, 23.51629844,
                             24.47327219, 25.51957398, 26.63575905, 27.80238264, 29.        ]])
 
-        assert_near_equal(akima_y.flatten(), prob['akima1.y_val'].flatten(), tolerance=1e-8)
+        assert_near_equal(akima_y.flatten(), prob.get_val('akima1.y_val').flatten(), tolerance=1e-8)
 
     def test_multi_splines(self):
 
@@ -458,7 +458,7 @@ class SplineCompFeatureTestCase(unittest.TestCase):
                              17.96032258, 20.14140712, 22.31181718, 24.40891577, 26.27368825, 27.74068235,
                              28.67782484, 29.        ]])
 
-        assert_near_equal(akima_y.flatten(), prob['akima1.y_val'].flatten(), tolerance=1e-8)
+        assert_near_equal(akima_y.flatten(), prob.get_val('akima1.y_val').flatten(), tolerance=1e-8)
 
     def test_akima_options(self):
         import numpy as np
@@ -502,21 +502,18 @@ class SplineCompFeatureTestCase(unittest.TestCase):
         tt = np.linspace(0, 3.0*np.pi, n_point)
         x = np.sin(t)
 
-        model.add_subsystem('px', om.IndepVarComp('x', val=x))
-
         # Set options specific to bsplines
         bspline_options = {'order': 3}
 
         comp = om.SplineComp(method='bsplines', x_interp_val=tt, num_cp=n_cp,
                             interp_options=bspline_options)
 
-        prob.model.add_subsystem('interp', comp)
+        prob.model.add_subsystem('interp', comp, promotes_inputs=[('h_cp', 'x')])
 
         comp.add_spline(y_cp_name='h_cp', y_interp_name='h', y_cp_val=x, y_units=None)
 
-        model.connect('px.x', 'interp.h_cp')
-
         prob.setup(force_alloc_complex=True)
+        prob.set_val('x', x)
         prob.run_model()
 
     def test_2to3doc_fixed_grid(self):
