@@ -15,7 +15,7 @@ from openmdao.utils.units import valid_units
 from openmdao.utils.name_maps import rel_key2abs_key, abs_key2rel_key, rel_name2abs_name
 from openmdao.utils.mpi import MPI
 from openmdao.utils.general_utils import format_as_float_or_array, ensure_compatible, \
-    find_matches, simple_warning, make_set, _is_slice
+    find_matches, simple_warning, make_set, _is_slicer_op
 import openmdao.utils.coloring as coloring_mod
 
 
@@ -477,12 +477,11 @@ class Component(System):
         }
 
         if src_indices is not None:
-            if _is_slice(src_indices):
+            if _is_slicer_op(src_indices):
                 metadata['src_indices'] = src_indices
             else:
                 metadata['src_indices'] = np.asarray(src_indices, dtype=INT_DTYPE)
 
-        # We may not know the pathname yet, so we have to use name for now, instead of abs_name.
         if self._static_mode:
             var_rel2meta = self._static_var_rel2meta
             var_rel_names = self._static_var_rel_names
