@@ -81,9 +81,6 @@ class ImplicitComponent(Component):
         """
         Compute outputs. The model is assumed to be in a scaled state.
         """
-        # Reconfigure if needed.
-        super(ImplicitComponent, self)._solve_nonlinear()
-
         self._inputs.read_only = True
 
         try:
@@ -106,6 +103,7 @@ class ImplicitComponent(Component):
         Provide initial guess for states.
         """
         if self._has_guess:
+            self._apply_nonlinear()
             self._inputs.read_only = self._residuals.read_only = True
             complex_step = self._inputs._under_complex_step
 
