@@ -112,44 +112,35 @@ class ImplicitCompTestCase(unittest.TestCase):
     def setUp(self):
         group = om.Group()
 
-        comp1 = group.add_subsystem('comp1', om.IndepVarComp())
-        comp1.add_output('a', 1.0)
-        comp1.add_output('b', -4.0)
-        comp1.add_output('c', 3.0)
-
-        group.add_subsystem('comp2', QuadraticLinearize())
-        group.add_subsystem('comp3', QuadraticJacVec())
-
-        group.connect('comp1.a', 'comp2.a')
-        group.connect('comp1.b', 'comp2.b')
-        group.connect('comp1.c', 'comp2.c')
-
-        group.connect('comp1.a', 'comp3.a')
-        group.connect('comp1.b', 'comp3.b')
-        group.connect('comp1.c', 'comp3.c')
+        group.add_subsystem('comp1', QuadraticLinearize(), promotes_inputs=['a', 'b', 'c'])
+        group.add_subsystem('comp2', QuadraticJacVec(), promotes_inputs=['a', 'b', 'c'])
 
         prob = om.Problem(model=group)
         prob.setup()
 
+        prob.set_val('a', 1.0)
+        prob.set_val('b', -4.0)
+        prob.set_val('c', 3.0)
+
         self.prob = prob
 
     def test_compute_and_derivs(self):
         prob = self.prob
         prob.run_model()
 
-        assert_near_equal(prob['comp2.x'], 3.)
+        assert_near_equal(prob['comp1.x'], 3.)
         assert_near_equal(prob['comp2.x'], 3.)
 
         total_derivs = prob.compute_totals(
-            wrt=['comp1.a', 'comp1.b', 'comp1.c'],
-            of=['comp2.x', 'comp3.x']
+            wrt=['a', 'b', 'c'],
+            of=['comp1.x', 'comp2.x']
         )
-        assert_near_equal(total_derivs['comp2.x', 'comp1.a'], [[-4.5]])
-        assert_near_equal(total_derivs['comp2.x', 'comp1.b'], [[-1.5]])
-        assert_near_equal(total_derivs['comp2.x', 'comp1.c'], [[-0.5]])
-        assert_near_equal(total_derivs['comp3.x', 'comp1.a'], [[-4.5]])
-        assert_near_equal(total_derivs['comp3.x', 'comp1.b'], [[-1.5]])
-        assert_near_equal(total_derivs['comp3.x', 'comp1.c'], [[-0.5]])
+        assert_near_equal(total_derivs['comp1.x', 'a'], [[-4.5]])
+        assert_near_equal(total_derivs['comp1.x', 'b'], [[-1.5]])
+        assert_near_equal(total_derivs['comp1.x', 'c'], [[-0.5]])
+        assert_near_equal(total_derivs['comp2.x', 'a'], [[-4.5]])
+        assert_near_equal(total_derivs['comp2.x', 'b'], [[-1.5]])
+        assert_near_equal(total_derivs['comp2.x', 'c'], [[-0.5]])
 
     def test_list_inputs_before_run(self):
         # cannot list_inputs on a Group before running
@@ -237,16 +228,16 @@ class ImplicitCompTestCase(unittest.TestCase):
         stream = StringIO()
         inputs = self.prob.model.list_inputs(hierarchical=False, desc=True, out_stream=stream)
         self.assertEqual(sorted(inputs), [
+            ('comp1.a', {'value':  [1.], 'desc': ''}),
+            ('comp1.b', {'value': [-4.], 'desc': ''}),
+            ('comp1.c', {'value':  [3.], 'desc': ''}),
             ('comp2.a', {'value':  [1.], 'desc': ''}),
             ('comp2.b', {'value': [-4.], 'desc': ''}),
-            ('comp2.c', {'value':  [3.], 'desc': ''}),
-            ('comp3.a', {'value':  [1.], 'desc': ''}),
-            ('comp3.b', {'value': [-4.], 'desc': ''}),
-            ('comp3.c', {'value':  [3.], 'desc': ''})
+            ('comp2.c', {'value':  [3.], 'desc': ''})
         ])
         text = stream.getvalue()
+        self.assertEqual(text.count('comp1.'), 3)
         self.assertEqual(text.count('comp2.'), 3)
-        self.assertEqual(text.count('comp3.'), 3)
         self.assertEqual(text.count('value'), 1)
 
     def test_list_inputs_with_tags(self):
@@ -255,19 +246,19 @@ class ImplicitCompTestCase(unittest.TestCase):
         # No tags
         inputs = self.prob.model.list_inputs(values=False, hierarchical=False, out_stream=None)
         self.assertEqual(sorted(inputs), [
+            ('comp1.a', {}),
+            ('comp1.b', {}),
+            ('comp1.c', {}),
             ('comp2.a', {}),
             ('comp2.b', {}),
-            ('comp2.c', {}),
-            ('comp3.a', {}),
-            ('comp3.b', {}),
-            ('comp3.c', {})
+            ('comp2.c', {})
         ])
 
         # With tag
         inputs = self.prob.model.list_inputs(values=False, hierarchical=False, out_stream=None, tags='tag_a')
         self.assertEqual(sorted(inputs), [
+            ('comp1.a', {}),
             ('comp2.a', {}),
-            ('comp3.a', {}),
         ])
 
         # Wrong tag
@@ -282,13 +273,11 @@ class ImplicitCompTestCase(unittest.TestCase):
                                              out_stream=stream)
 
         text = stream.getvalue()
+        print(text)
 
-        self.assertEqual(text.count('comp2.a'), 1)
-        self.assertEqual(text.count('comp2.b'), 1)
-        self.assertEqual(text.count('comp2.c'), 1)
-        self.assertEqual(text.count('comp3.a'), 1)
-        self.assertEqual(text.count('comp3.b'), 1)
-        self.assertEqual(text.count('comp3.c'), 1)
+        self.assertEqual(text.count('  a  '), 4)
+        self.assertEqual(text.count('  b  '), 4)
+        self.assertEqual(text.count('  c  '), 4)
 
         num_non_empty_lines = sum([1 for s in text.splitlines() if s.strip()])
         self.assertEqual(num_non_empty_lines, 13)
@@ -298,15 +287,9 @@ class ImplicitCompTestCase(unittest.TestCase):
 
         stream = StringIO()
         outputs = self.prob.model.list_outputs(implicit=False, hierarchical=False, out_stream=stream)
-        self.assertEqual(sorted(outputs), [
-            ('comp1.a', {'value': [1.]}),
-            ('comp1.b', {'value': [-4.]}),
-            ('comp1.c', {'value': [3.]})
-        ])
+        self.assertEqual([], sorted(outputs))
         text = stream.getvalue()
-        self.assertEqual(text.count('comp1.'), 3)
-        self.assertEqual(text.count('varname'), 1)
-        self.assertEqual(text.count('value'), 1)
+        self.assertIn('0 Explicit Output(s) in \'model\'', text)
 
     def test_list_explicit_outputs_with_tags(self):
         self.prob.run_model()
@@ -314,16 +297,16 @@ class ImplicitCompTestCase(unittest.TestCase):
         # No tags
         outputs = self.prob.model.list_outputs(explicit=False, hierarchical=False, out_stream=None)
         self.assertEqual(sorted(outputs), [
+            ('comp1.x', {'value': [3.]}),
             ('comp2.x', {'value': [3.]}),
-            ('comp3.x', {'value': [3.]}),
         ])
 
         # With tag
         outputs = self.prob.model.list_outputs(explicit=False, hierarchical=False, out_stream=None,
                                                tags="tag_x")
         self.assertEqual(sorted(outputs), [
+            ('comp1.x', {'value': [3.]}),
             ('comp2.x', {'value': [3.]}),
-            ('comp3.x', {'value': [3.]}),
         ])
 
         # Wrong tag
@@ -337,11 +320,11 @@ class ImplicitCompTestCase(unittest.TestCase):
         stream = StringIO()
         states = self.prob.model.list_outputs(explicit=False, residuals=True,
                                               hierarchical=False, out_stream=stream)
+        self.assertTrue(('comp1.x', {'value': [3.], 'resids': [0.]}) in states, msg=None)
         self.assertTrue(('comp2.x', {'value': [3.], 'resids': [0.]}) in states, msg=None)
-        self.assertTrue(('comp3.x', {'value': [3.], 'resids': [0.]}) in states, msg=None)
         text = stream.getvalue()
+        self.assertEqual(1, text.count('comp1.x'))
         self.assertEqual(1, text.count('comp2.x'))
-        self.assertEqual(1, text.count('comp3.x'))
         self.assertEqual(1, text.count('value'))
         self.assertEqual(1, text.count('resids'))
 
@@ -354,8 +337,8 @@ class ImplicitCompTestCase(unittest.TestCase):
                                               out_stream=stream)
 
         text = stream.getvalue()
+        self.assertEqual(text.count('comp1.x'), 1)
         self.assertEqual(text.count('comp2.x'), 1)
-        self.assertEqual(text.count('comp3.x'), 1)
         num_non_empty_lines = sum([1 for s in text.splitlines() if s.strip()])
         self.assertEqual(num_non_empty_lines, 9)
 
@@ -366,19 +349,16 @@ class ImplicitCompTestCase(unittest.TestCase):
         resids = self.prob.model.list_outputs(values=False, residuals=True, hierarchical=False,
                                               out_stream=stream)
         self.assertEqual(sorted(resids), [
-            ('comp1.a', {'resids': [0.]}),
-            ('comp1.b', {'resids': [0.]}),
-            ('comp1.c', {'resids': [0.]}),
-            ('comp2.x', {'resids': [0.]}),
-            ('comp3.x', {'resids': [0.]})
+            ('comp1.x', {'resids': [0.]}),
+            ('comp2.x', {'resids': [0.]})
         ])
         text = stream.getvalue()
-        self.assertEqual(text.count('comp1.'), 3)
+        self.assertEqual(text.count('comp1.'), 1)
+        self.assertEqual(text.count('comp1.x'), 1)
         self.assertEqual(text.count('comp2.x'), 1)
-        self.assertEqual(text.count('comp3.x'), 1)
-        self.assertEqual(text.count('varname'), 2)
+        self.assertEqual(text.count('varname'), 1)
         self.assertEqual(text.count('value'), 0)
-        self.assertEqual(text.count('resids'), 2)
+        self.assertEqual(text.count('resids'), 1)
 
 
 class ImplicitCompGuessTestCase(unittest.TestCase):
@@ -498,7 +478,117 @@ class ImplicitCompGuessTestCase(unittest.TestCase):
         totals = prob.check_totals(of=['fn.y'], wrt=['p.a'], method='cs', out_stream=None)
 
         for key, val in totals.items():
-            assert_near_equal(val['rel error'][0], 0.0, 1e-9)
+            assert_near_equal(val['rel error'][0], 0.0, 3e-9)
+
+    def test_guess_nonlinear_residuals(self):
+
+        class ImpWithInitial(om.ImplicitComponent):
+            """
+            An implicit component to solve the quadratic equation: x^2 - 4x + 3
+            (solutions at x=1 and x=3)
+            """
+            def setup(self):
+                self.add_input('a', val=1.)
+                self.add_input('b', val=-4.)
+                self.add_input('c', val=3.)
+
+                self.add_output('x', val=0.)
+
+                self.declare_partials(of='*', wrt='*')
+
+            def apply_nonlinear(self, inputs, outputs, residuals):
+                a = inputs['a']
+                b = inputs['b']
+                c = inputs['c']
+                x = outputs['x']
+                residuals['x'] = a * x ** 2 + b * x + c
+
+            def linearize(self, inputs, outputs, partials):
+                a = inputs['a']
+                b = inputs['b']
+                c = inputs['c']
+                x = outputs['x']
+
+                partials['x', 'a'] = x ** 2
+                partials['x', 'b'] = x
+                partials['x', 'c'] = 1.0
+                partials['x', 'x'] = 2 * a * x + b
+
+            def guess_nonlinear(self, inputs, outputs, resids):
+                # Default initial state of zero for x takes us to x=1 solution.
+                # Here we set it to a value that will take us to the x=3 solution.
+                outputs['x'] = 5.0
+                assert(resids['x'] != 0.)
+
+        prob = om.Problem()
+        model = prob.model
+
+        model.add_subsystem('comp', ImpWithInitial())
+
+        model.nonlinear_solver = om.NewtonSolver(solve_subsystems=False)
+        model.linear_solver = om.ScipyKrylov()
+
+        prob.setup()
+        prob['comp.x'] = 10
+        prob.run_model()
+
+    def test_guess_nonlinear_group_residual(self):
+        # Test that data is transfered to a component before calling guess_nonlinear.
+
+        class ImpWithInitial(om.ImplicitComponent):
+            """
+            An implicit component to solve the quadratic equation: x^2 - 4x + 3
+            (solutions at x=1 and x=3)
+            """
+            def setup(self):
+                self.add_input('a', val=1.)
+                self.add_input('b', val=-4.)
+                self.add_input('c', val=3.)
+
+                self.add_output('x', val=0.)
+
+                self.declare_partials(of='*', wrt='*')
+
+            def apply_nonlinear(self, inputs, outputs, residuals):
+                a = inputs['a']
+                b = inputs['b']
+                c = inputs['c']
+                x = outputs['x']
+                residuals['x'] = a * x ** 2 + b * x + c
+
+            def linearize(self, inputs, outputs, partials):
+                a = inputs['a']
+                b = inputs['b']
+                c = inputs['c']
+                x = outputs['x']
+
+                partials['x', 'a'] = x ** 2
+                partials['x', 'b'] = x
+                partials['x', 'c'] = 1.0
+                partials['x', 'x'] = 2 * a * x + b
+
+            def guess_nonlinear(self, inputs, outputs, resids):
+                # Default initial state of zero for x takes us to x=1 solution.
+                # Here we set it to a value that will take us to the x=3 solution.
+                outputs['x'] = 5.0
+                assert(resids['x'] != 0.)
+
+        group = om.Group()
+
+        group.add_subsystem('px', om.IndepVarComp('x', -1.0))
+        group.add_subsystem('comp1', ImpWithInitial())
+        group.add_subsystem('comp2', ImpWithInitial())
+        group.connect('px.x', 'comp1.a')
+        group.connect('comp1.x', 'comp2.a')
+
+        group.nonlinear_solver = om.NewtonSolver(solve_subsystems=False)
+        group.linear_solver = om.ScipyKrylov()
+
+        prob = om.Problem(model=group)
+        prob.set_solver_print(level=0)
+        prob.setup()
+
+        prob.run_model()
 
     def test_guess_nonlinear_transfer(self):
         # Test that data is transfered to a component before calling guess_nonlinear.
@@ -627,6 +717,7 @@ class ImplicitCompGuessTestCase(unittest.TestCase):
 
     def test_guess_nonlinear_feature(self):
         import openmdao.api as om
+        import numpy as np
 
         class ImpWithInitial(om.ImplicitComponent):
             """
@@ -661,9 +752,11 @@ class ImplicitCompGuessTestCase(unittest.TestCase):
                 partials['x', 'x'] = 2 * a * x + b
 
             def guess_nonlinear(self, inputs, outputs, resids):
-                # Default initial state of zero for x takes us to x=1 solution.
-                # Here we set it to a value that will take us to the x=3 solution.
-                outputs['x'] = 5.0
+                # Check residuals
+                if np.abs(resids['x']) > 1.0E-2:
+                    # Default initial state of zero for x takes us to x=1 solution.
+                    # Here we set it to a value that will take us to the x=3 solution.
+                    outputs['x'] = 5.0
 
         prob = om.Problem()
         model = prob.model
@@ -708,7 +801,7 @@ class ImplicitCompGuessTestCase(unittest.TestCase):
             prob.run_model()
 
         self.assertEqual(str(cm.exception),
-                         "Attempt to set value of 'x' in input vector "
+                         "ImpWithInitial (comp1): Attempt to set value of 'x' in input vector "
                          "when it is read only.")
 
     def test_guess_nonlinear_inputs_read_only_reset(self):
@@ -772,7 +865,7 @@ class ImplicitCompGuessTestCase(unittest.TestCase):
             prob.run_model()
 
         self.assertEqual(str(cm.exception),
-                         "Attempt to set value of 'y' in residual vector "
+                         "ImpWithInitial (comp1): Attempt to set value of 'y' in residual vector "
                          "when it is read only.")
 
 
@@ -794,7 +887,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_apply_nonlinear()
 
         self.assertEqual(str(cm.exception),
-                         "Attempt to set value of 'a' in input vector "
+                         "BadComp (bad): Attempt to set value of 'a' in input vector "
                          "when it is read only.")
 
     def test_apply_nonlinear_outputs_read_only(self):
@@ -813,7 +906,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_apply_nonlinear()
 
         self.assertEqual(str(cm.exception),
-                         "Attempt to set value of 'x' in output vector "
+                         "BadComp (bad): Attempt to set value of 'x' in output vector "
                          "when it is read only.")
 
     def test_apply_nonlinear_read_only_reset(self):
@@ -849,7 +942,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.run_model()
 
         self.assertEqual(str(cm.exception),
-                         "Attempt to set value of 'a' in input vector "
+                         "BadComp (bad): Attempt to set value of 'a' in input vector "
                          "when it is read only.")
 
     def test_solve_nonlinear_inputs_read_only_reset(self):
@@ -884,7 +977,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_linearize()
 
         self.assertEqual(str(cm.exception),
-                         "Attempt to set value of 'a' in input vector "
+                         "BadComp (bad): Attempt to set value of 'a' in input vector "
                          "when it is read only.")
 
     def test_linearize_outputs_read_only(self):
@@ -903,7 +996,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_linearize()
 
         self.assertEqual(str(cm.exception),
-                         "Attempt to set value of 'x' in output vector "
+                         "BadComp (bad): Attempt to set value of 'x' in output vector "
                          "when it is read only.")
 
     def test_linearize_read_only_reset(self):
@@ -941,7 +1034,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_apply_linear(['linear'], 'fwd')
 
         self.assertEqual(str(cm.exception),
-                         "Attempt to set value of 'a' in input vector "
+                         "BadComp (bad): Attempt to set value of 'a' in input vector "
                          "when it is read only.")
 
     def test_apply_linear_outputs_read_only(self):
@@ -961,7 +1054,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_apply_linear(['linear'], 'fwd')
 
         self.assertEqual(str(cm.exception),
-                         "Attempt to set value of 'x' in output vector "
+                         "BadComp (bad): Attempt to set value of 'x' in output vector "
                          "when it is read only.")
 
     def test_apply_linear_dinputs_read_only(self):
@@ -981,7 +1074,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_apply_linear(['linear'], 'fwd')
 
         self.assertEqual(str(cm.exception),
-                         "Attempt to set value of 'a' in input vector "
+                         "BadComp (bad): Attempt to set value of 'a' in input vector "
                          "when it is read only.")
 
     def test_apply_linear_doutputs_read_only(self):
@@ -1001,7 +1094,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_apply_linear(['linear'], 'fwd')
 
         self.assertEqual(str(cm.exception),
-                         "Attempt to set value of 'x' in output vector "
+                         "BadComp (bad): Attempt to set value of 'x' in output vector "
                          "when it is read only.")
 
     def test_apply_linear_dresids_read_only(self):
@@ -1021,7 +1114,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_apply_linear(['linear'], 'rev')
 
         self.assertEqual(str(cm.exception),
-                         "Attempt to set value of 'x' in residual vector "
+                         "BadComp (bad): Attempt to set value of 'x' in residual vector "
                          "when it is read only.")
 
     def test_apply_linear_read_only_reset(self):
@@ -1061,7 +1154,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_solve_linear(['linear'], 'rev')
 
         self.assertEqual(str(cm.exception),
-                         "Attempt to set value of 'x' in output vector "
+                         "BadComp (bad): Attempt to set value of 'x' in output vector "
                          "when it is read only.")
 
     def test_solve_linear_dresids_read_only(self):
@@ -1081,7 +1174,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_solve_linear(['linear'], 'fwd')
 
         self.assertEqual(str(cm.exception),
-                         "Attempt to set value of 'x' in residual vector "
+                         "BadComp (bad): Attempt to set value of 'x' in residual vector "
                          "when it is read only.")
 
     def test_solve_linear_read_only_reset(self):
@@ -1111,30 +1204,18 @@ class ListFeatureTestCase(unittest.TestCase):
 
         group = om.Group()
 
-        comp1 = group.add_subsystem('comp1', om.IndepVarComp())
-        comp1.add_output('a', 1.0)
-        comp1.add_output('b', 1.0)
-        comp1.add_output('c', 1.0)
+        sub = group.add_subsystem('sub', om.Group(), promotes_inputs=['a', 'b', 'c'])
 
-        sub = group.add_subsystem('sub', om.Group())
-        sub.add_subsystem('comp2', QuadraticComp())
-        sub.add_subsystem('comp3', QuadraticComp())
-
-        group.connect('comp1.a', 'sub.comp2.a')
-        group.connect('comp1.b', 'sub.comp2.b')
-        group.connect('comp1.c', 'sub.comp2.c')
-
-        group.connect('comp1.a', 'sub.comp3.a')
-        group.connect('comp1.b', 'sub.comp3.b')
-        group.connect('comp1.c', 'sub.comp3.c')
+        sub.add_subsystem('comp1', QuadraticComp(), promotes_inputs=['a', 'b', 'c'])
+        sub.add_subsystem('comp2', QuadraticComp(), promotes_inputs=['a', 'b', 'c'])
 
         global prob
         prob = om.Problem(model=group)
         prob.setup()
 
-        prob['comp1.a'] = 1.
-        prob['comp1.b'] = -4.
-        prob['comp1.c'] = 3.
+        prob.set_val('a', 1.)
+        prob.set_val('b', -4.)
+        prob.set_val('c', 3.)
         prob.run_model()
 
     def test_list_inputs(self):
@@ -1159,20 +1240,12 @@ class ListFeatureTestCase(unittest.TestCase):
         # list inputs
         inputs = prob.model.list_inputs(out_stream=None)
         self.assertEqual(sorted(inputs), [
+            ('sub.comp1.a', {'value': [1.]}),
+            ('sub.comp1.b', {'value': [-4.]}),
+            ('sub.comp1.c', {'value': [3.]}),
             ('sub.comp2.a', {'value': [1.]}),
             ('sub.comp2.b', {'value': [-4.]}),
-            ('sub.comp2.c', {'value': [3.]}),
-            ('sub.comp3.a', {'value': [1.]}),
-            ('sub.comp3.b', {'value': [-4.]}),
-            ('sub.comp3.c', {'value': [3.]})
-        ])
-
-        # list explicit outputs
-        outputs = prob.model.list_outputs(implicit=False, out_stream=None)
-        self.assertEqual(sorted(outputs), [
-            ('comp1.a', {'value': [1.]}),
-            ('comp1.b', {'value': [-4.]}),
-            ('comp1.c', {'value': [3.]})
+            ('sub.comp2.c', {'value': [3.]})
         ])
 
     def test_for_docs_list_no_values(self):
@@ -1195,20 +1268,12 @@ class ListFeatureTestCase(unittest.TestCase):
         # list inputs
         inputs = prob.model.list_inputs(values=False)
         self.assertEqual([n[0] for n in sorted(inputs)], [
+            'sub.comp1.a',
+            'sub.comp1.b',
+            'sub.comp1.c',
             'sub.comp2.a',
             'sub.comp2.b',
-            'sub.comp2.c',
-            'sub.comp3.a',
-            'sub.comp3.b',
-            'sub.comp3.c'
-        ])
-
-        # list only explicit outputs
-        outputs = prob.model.list_outputs(implicit=False, values=False)
-        self.assertEqual([n[0] for n in sorted(outputs)], [
-            'comp1.a',
-            'comp1.b',
-            'comp1.c'
+            'sub.comp2.c'
         ])
 
     def test_simple_list_vars_options(self):
