@@ -152,10 +152,9 @@ class TestParallelGroups(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p1', om.IndepVarComp('x', 1.0))
-        model.add_subsystem('p2', om.IndepVarComp('x', 1.0))
+        model.set_input_defaults('x', 1.)
 
-        parallel = model.add_subsystem('parallel', om.ParallelGroup())
+        parallel = model.add_subsystem('parallel', om.ParallelGroup(), promotes_inputs=[('c1.x', 'x'), ('c2.x', 'x')])
         parallel.add_subsystem('c1', om.ExecComp(['y=-2.0*x']))
         parallel.add_subsystem('c2', om.ExecComp(['y=5.0*x']))
 
@@ -164,9 +163,6 @@ class TestParallelGroups(unittest.TestCase):
         model.connect("parallel.c1.y", "c3.x1")
         model.connect("parallel.c2.y", "c3.x2")
 
-        model.connect("p1.x", "parallel.c1.x")
-        model.connect("p2.x", "parallel.c2.x")
-
         prob.setup(check=False, mode='fwd')
         prob.run_model()
 
@@ -375,14 +371,16 @@ class TestParallelListStates(unittest.TestCase):
             def solve_nonlinear(self, inputs, outputs):
                 outputs['x'] = np.linalg.solve(self.mtx, inputs['rhs'])
 
-        p = om.Problem(model=om.ParallelGroup())
-        p.model.add_subsystem('C1', StateComp())
-        p.model.add_subsystem('C2', StateComp())
-        p.model.add_subsystem('C3', om.ExecComp('y=2.0*x'))
-        p.model.add_subsystem('C4', StateComp())
+        p = om.Problem()
+        par = p.model.add_subsystem('par', om.ParallelGroup())
+        par.add_subsystem('C1', StateComp())
+        par.add_subsystem('C2', StateComp())
+        par.add_subsystem('C3', om.ExecComp('y=2.0*x'))
+        par.add_subsystem('C4', StateComp())
+
         p.setup()
         p.final_setup()
-        self.assertEqual(sorted(p.model._list_states_allprocs()), ['C1.x', 'C2.x', 'C4.x'])
+        self.assertEqual(sorted(p.model._list_states_allprocs()), ['par.C1.x', 'par.C2.x', 'par.C4.x'])
 
 
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
