@@ -5,7 +5,7 @@ from openmdao.api import Problem, Group, ExecComp
 from openmdao.api import Group, ParallelGroup, Problem, IndepVarComp, LinearBlockGS, \
     ExecComp, ExplicitComponent, PETScVector, ScipyKrylov, NonlinearBlockGS
 from openmdao.utils.mpi import MPI
-from openmdao.utils.assert_utils import assert_rel_error
+from openmdao.utils.assert_utils import assert_near_equal
 
 try:
     from openmdao.api import PETScVector
@@ -63,10 +63,10 @@ class ProcTestCase2(unittest.TestCase):
         self.assertEqual(all_inds, [[0,1],[2,3]])
 
         p.run_model()
-        assert_rel_error(self, p['objective.y'], 8.0)
+        assert_near_equal(p['objective.y'], 8.0)
 
         J = p.compute_totals(['objective.y'], ['indep.x'], return_format='dict')
-        assert_rel_error(self, J['objective.y']['indep.x'][0][0], 8.0, 1e-6)
+        assert_near_equal(J['objective.y']['indep.x'][0][0], 8.0, 1e-6)
 
 
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
@@ -81,10 +81,10 @@ class ProcTestCase3(unittest.TestCase):
 
         p.run_model()
 
-        assert_rel_error(self, p['objective.y'], 6.0)
+        assert_near_equal(p['objective.y'], 6.0)
 
         J = p.compute_totals(['objective.y'], ['indep.x'], return_format='dict')
-        assert_rel_error(self, J['objective.y']['indep.x'][0][0], 6.0, 1e-6)
+        assert_near_equal(J['objective.y']['indep.x'][0][0], 6.0, 1e-6)
 
     def test_4_subs(self):
         p = _build_model(nsubs=4)
@@ -92,10 +92,10 @@ class ProcTestCase3(unittest.TestCase):
         self.assertEqual(all_inds, [[0, 1], [2], [3]])
 
         p.run_model()
-        assert_rel_error(self, p['objective.y'], 8.0)
+        assert_near_equal(p['objective.y'], 8.0)
 
         J = p.compute_totals(['objective.y'], ['indep.x'], return_format='dict')
-        assert_rel_error(self, J['objective.y']['indep.x'][0][0], 8.0, 1e-6)
+        assert_near_equal(J['objective.y']['indep.x'][0][0], 8.0, 1e-6)
 
     def test_4_subs_max2(self):
         p = _build_model(nsubs=4, max_procs=[2,2,2,2])
@@ -103,10 +103,10 @@ class ProcTestCase3(unittest.TestCase):
         self.assertEqual(all_inds, [[0, 1], [2], [3]])
 
         p.run_model()
-        assert_rel_error(self, p['objective.y'], 8.0)
+        assert_near_equal(p['objective.y'], 8.0)
 
         J = p.compute_totals(['objective.y'], ['indep.x'], return_format='dict')
-        assert_rel_error(self, J['objective.y']['indep.x'][0][0], 8.0, 1e-6)
+        assert_near_equal(J['objective.y']['indep.x'][0][0], 8.0, 1e-6)
 
     def test_4_subs_with_mins(self):
         try:
@@ -151,10 +151,10 @@ class ProcTestCase3(unittest.TestCase):
         self.assertEqual(all_inds, [[0], [1], [1]])
 
         p.run_model()
-        assert_rel_error(self, p['objective.y'], 8.0)
+        assert_near_equal(p['objective.y'], 8.0)
 
         J = p.compute_totals(['objective.y'], ['indep.x'], return_format='dict')
-        assert_rel_error(self, J['objective.y']['indep.x'][0][0], 8.0, 1e-6)
+        assert_near_equal(J['objective.y']['indep.x'][0][0], 8.0, 1e-6)
 
 
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
@@ -168,10 +168,10 @@ class ProcTestCase5(unittest.TestCase):
         self.assertEqual(all_inds, [[0], [0], [1], [2], [3]])
 
         p.run_model()
-        assert_rel_error(self, p['objective.y'], 8.0)
+        assert_near_equal(p['objective.y'], 8.0)
 
         J = p.compute_totals(['objective.y'], ['indep.x'], return_format='dict')
-        assert_rel_error(self, J['objective.y']['indep.x'][0][0], 8.0, 1e-6)
+        assert_near_equal(J['objective.y']['indep.x'][0][0], 8.0, 1e-6)
 
 
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
@@ -199,10 +199,10 @@ class ProcTestCase8(unittest.TestCase):
         self.assertEqual(all_inds, [[0], [1], [1], [2], [3], [3], [3], [3]])
 
         p.run_model()
-        assert_rel_error(self, p['objective.y'], 8.0)
+        assert_near_equal(p['objective.y'], 8.0)
 
         J = p.compute_totals(['objective.y'], ['indep.x'], return_format='dict')
-        assert_rel_error(self, J['objective.y']['indep.x'][0][0], 8.0, 1e-6)
+        assert_near_equal(J['objective.y']['indep.x'][0][0], 8.0, 1e-6)
 
 
 if __name__ == "__main__":
