@@ -82,13 +82,11 @@ class AssembledJacobian(Jacobian):
         OrderedDict
             Tuples of the form (start, end) keyed on variable name.
         """
-        iproc = system.comm.rank
-        abs2idx = system._var_allprocs_abs2idx['linear']
-        sizes = system._var_sizes['linear'][vtype]
-        start = end = 0
+        abs2meta = system._var_abs2meta
         ranges = OrderedDict()
+        start = end = 0
         for name in system._var_abs_names[vtype]:
-            end += sizes[iproc, abs2idx[name]]
+            end += abs2meta[name]['size']
             ranges[name] = (start, end)
             start = end
         return ranges
@@ -112,7 +110,6 @@ class AssembledJacobian(Jacobian):
         ext_mtx = self._matrix_class(system.comm, False)
 
         iproc = system.comm.rank
-        in_sizes = system._var_sizes['nonlinear']['input']
         out_ranges = self._out_ranges
         in_ranges = self._in_ranges
 
@@ -181,12 +178,11 @@ class AssembledJacobian(Jacobian):
                     shape = (res_size, in_end - in_offset)
                     ext_mtx._add_submat(abs_key, info, res_offset, in_offset, None, shape)
 
-        out_size = system._outputs._data.size
+        out_size = len(system._outputs)
         int_mtx._build(out_size, out_size, system)
 
         if ext_mtx._submats:
-            in_size = np.sum(in_sizes[iproc, :])
-            ext_mtx._build(out_size, in_size)
+            ext_mtx._build(out_size, len(system._vectors['input']['linear']))
         else:
             ext_mtx = None
 
@@ -231,14 +227,14 @@ class AssembledJacobian(Jacobian):
         conns = {} if isinstance(system, Component) else system._conn_global_abs_in2out
 
         iproc = system.comm.rank
-        sizes = system._var_sizes['nonlinear']['input']
-        abs2idx = system._var_allprocs_abs2idx['nonlinear']
+        sizes = system._var_sizes['linear']['input']
+        abs2idx = system._var_allprocs_abs2idx['linear']
         in_offset = {n: np.sum(sizes[iproc, :abs2idx[n]]) for n in
                      system._var_abs_names['input'] if n not in conns}
 
         subjacs_info = self._subjacs_info
 
-        sizes = system._var_sizes['nonlinear']['output']
+        sizes = system._var_sizes['linear']['output']
         for s in system.system_iter(recurse=True, include_self=True, typ=Component):
             for res_abs_name in s._var_abs_names['output']:
                 res_offset = np.sum(sizes[iproc, :abs2idx[res_abs_name]])
@@ -256,11 +252,8 @@ class AssembledJacobian(Jacobian):
                                             in_offset[in_abs_name] - ranges[2], None, info['shape'])
 
         if ext_mtx._submats:
-            sizes = system._var_sizes
-            iproc = system.comm.rank
-            out_size = np.sum(sizes['nonlinear']['output'][iproc, :])
-            in_size = np.sum(sizes['nonlinear']['input'][iproc, :])
-            ext_mtx._build(out_size, in_size)
+            ext_mtx._build(len(system._vectors['output']['linear']),
+                           len(system._vectors['input']['linear']))
         else:
             ext_mtx = None
 
