@@ -92,7 +92,7 @@ class NonlinearBlockGS(NonlinearSolver):
         system = self._system()
 
         if self.options['use_aitken']:
-            self._delta_outputs_n_1 = system._outputs._data.copy()
+            self._delta_outputs_n_1 = system._outputs.asarray(copy=True)
             self._theta_n_1 = 1.
 
         # When under a complex step from higher in the hierarchy, sometimes the step is too small
@@ -125,15 +125,15 @@ class NonlinearBlockGS(NonlinearSolver):
             theta_n_1 = self._theta_n_1
 
             # store a copy of the outputs, used to compute the change in outputs later
-            delta_outputs_n = outputs._data.copy()
+            delta_outputs_n = outputs.asarray(copy=True)
 
         if use_aitken or not self.options['use_apply_nonlinear']:
             # store a copy of the outputs
             if not self.options['use_apply_nonlinear']:
                 with system._unscaled_context(outputs=[outputs]):
-                    outputs_n = outputs._data.copy()
+                    outputs_n = outputs.asarray(copy=True)
             else:
-                outputs_n = outputs._data.copy()
+                outputs_n = outputs.asarray(copy=True)
 
         self._solver_info.append_subsolver()
         self._gs_iter()
@@ -154,8 +154,8 @@ class NonlinearBlockGS(NonlinearSolver):
 
                 # If MPI, piggyback on the residual vector to perform a distributed norm.
                 if system.comm.size > 1:
-                    backup_r = residuals._data.copy()
-                    residuals._data[:] = temp
+                    backup_r = residuals.asarray(copy=True)
+                    residuals.set_val(temp)
                     temp_norm = residuals.get_norm()
                 else:
                     temp_norm = np.linalg.norm(temp)
@@ -166,11 +166,11 @@ class NonlinearBlockGS(NonlinearSolver):
                 # If MPI, piggyback on the output and residual vectors to perform a distributed
                 # dot product.
                 if system.comm.size > 1:
-                    backup_o = outputs._data.copy()
-                    outputs._data[:] = delta_outputs_n
+                    backup_o = outputs.asarray(copy=True)
+                    outputs.set_val(delta_outputs_n)
                     tddo = residuals.dot(outputs)
-                    residuals._data[:] = backup_r
-                    outputs._data[:] = backup_o
+                    residuals.set_val(backup_r)
+                    outputs.set_val(backup_o)
                 else:
                     tddo = temp.dot(delta_outputs_n)
 
@@ -186,9 +186,9 @@ class NonlinearBlockGS(NonlinearSolver):
 
             if not self.options['use_apply_nonlinear']:
                 with system._unscaled_context(outputs=[outputs]):
-                    outputs._data[:] = outputs_n
+                    outputs.set_val(outputs_n)
             else:
-                outputs._data[:] = outputs_n
+                outputs.set_val(outputs_n)
 
             # compute relaxed outputs
             outputs._data += theta_n * delta_outputs_n
@@ -199,7 +199,7 @@ class NonlinearBlockGS(NonlinearSolver):
         if not self.options['use_apply_nonlinear']:
             # Residual is the change in the outputs vector.
             with system._unscaled_context(outputs=[outputs], residuals=[residuals]):
-                residuals._data[:] = outputs._data - outputs_n
+                residuals.set_val(outputs._data - outputs_n)
 
     def _run_apply(self):
         """
@@ -228,7 +228,7 @@ class NonlinearBlockGS(NonlinearSolver):
             residuals = system._residuals
 
             with system._unscaled_context(outputs=[outputs]):
-                outputs_n = outputs._data.copy()
+                outputs_n = outputs.asarray(copy=True)
 
             self._solver_info.append_subsolver()
             for isub, subsys in enumerate(system._subsystems_allprocs):
@@ -238,7 +238,7 @@ class NonlinearBlockGS(NonlinearSolver):
 
             self._solver_info.pop()
             with system._unscaled_context(residuals=[residuals]):
-                residuals._data[:] = outputs._data - outputs_n
+                residuals.set_val(outputs._data - outputs_n)
 
     def _mpi_print_header(self):
         """
