@@ -37,8 +37,7 @@ class PETScVector(DefaultVector):
     TRANSFER = PETScTransfer
     cite = CITATION
 
-    def __init__(self, name, kind, system, root_vector=None, alloc_complex=False,
-                 ncol=1, relevant=None):
+    def __init__(self, name, kind, system, root_vector=None, alloc_complex=False, ncol=1):
         """
         Initialize all attributes.
 
@@ -56,13 +55,9 @@ class PETScVector(DefaultVector):
             Whether to allocate any imaginary storage to perform complex step. Default is False.
         ncol : int
             Number of columns for multi-vectors.
-        relevant : dict
-            Mapping of a VOI to a tuple containing dependent inputs, dependent outputs,
-            and dependent systems.
         """
         super(PETScVector, self).__init__(name, kind, system, root_vector=root_vector,
-                                          alloc_complex=alloc_complex, ncol=ncol,
-                                          relevant=relevant)
+                                          alloc_complex=alloc_complex, ncol=ncol)
 
         self._dup_inds = None
 
@@ -151,7 +146,7 @@ class PETScVector(DefaultVector):
 
         if self._ncol == 1:
             if has_dups:
-                data_cache = self._data.copy()
+                data_cache = self.asarray(copy=True)
                 data_cache[dup_inds] = 0.0
             else:
                 data_cache = self._data
